@@ -26,17 +26,7 @@
 # Author: Daniele Bigoni
 #
 
-
-"""
-
-Created on Wed Jul 11 10:40:30 2012
-
-@author: Daniele Bigoni (dabi@imm.dtu.dk)
-
-UncertaintyQuantificationToolbox is the collection of tools for Uncertainty Quantification.
-
-@copyright: 2012-2014 The Technical University of Denmark
-"""
+from _version import __version__
 
 import aux
 from aux import *
