@@ -28,7 +28,7 @@ import sys
 import numpy as np
 import numpy.linalg as npla
 import scipy.stats as stats
-import pickle as pkl
+import cPickle as pkl
 import UQToolbox.RandomSampling as RS
 from aux import bcolors
 
